## Sundew

**A carnivorous honeypot for AI agents**

Sundew deploys realistic-looking services that attract autonomous AI agents, then fingerprints and classifies their behavior. Each deployment is unique -- powered by a persona engine that makes every instance indistinguishable from a real service.

Named after the [sundew plant](https://en.wikipedia.org/wiki/Drosera) -- a carnivorous plant with sticky tentacles that traps everything that touches it.

[Documentation](https://docs.sundew.sh) -- [Quick Start](https://docs.sundew.sh/getting-started/quickstart) -- [Research](https://docs.sundew.sh/research/findings) -- [Contributing](https://github.com/sundew-sh/sundew/blob/main/CONTRIBUTING.md)
